diff --git a/osinaweb/billing/add/__pycache__/urls.cpython-312.pyc b/osinaweb/billing/add/__pycache__/urls.cpython-312.pyc
index 06afd047..a57ddb75 100644
Binary files a/osinaweb/billing/add/__pycache__/urls.cpython-312.pyc and b/osinaweb/billing/add/__pycache__/urls.cpython-312.pyc differ
diff --git a/osinaweb/billing/add/__pycache__/views.cpython-312.pyc b/osinaweb/billing/add/__pycache__/views.cpython-312.pyc
index d7ea02c4..b7b7328d 100644
Binary files a/osinaweb/billing/add/__pycache__/views.cpython-312.pyc and b/osinaweb/billing/add/__pycache__/views.cpython-312.pyc differ
diff --git a/osinaweb/db.sqlite3 b/osinaweb/db.sqlite3
index a2962fc2..fb1d5610 100644
Binary files a/osinaweb/db.sqlite3 and b/osinaweb/db.sqlite3 differ
diff --git a/osinaweb/osinacore/__pycache__/models.cpython-312.pyc b/osinaweb/osinacore/__pycache__/models.cpython-312.pyc
index 1c3e695e..2ab8a9a1 100644
Binary files a/osinaweb/osinacore/__pycache__/models.cpython-312.pyc and b/osinaweb/osinacore/__pycache__/models.cpython-312.pyc differ
diff --git a/osinaweb/osinacore/add/__pycache__/views.cpython-312.pyc b/osinaweb/osinacore/add/__pycache__/views.cpython-312.pyc
index 17cbfcf5..667211f0 100644
Binary files a/osinaweb/osinacore/add/__pycache__/views.cpython-312.pyc and b/osinaweb/osinacore/add/__pycache__/views.cpython-312.pyc differ
diff --git a/osinaweb/osinacore/edit/__pycache__/views.cpython-312.pyc b/osinaweb/osinacore/edit/__pycache__/views.cpython-312.pyc
index ca2065a2..ab9f82aa 100644
Binary files a/osinaweb/osinacore/edit/__pycache__/views.cpython-312.pyc and b/osinaweb/osinacore/edit/__pycache__/views.cpython-312.pyc differ
diff --git a/osinaweb/osinacore/migrations/__pycache__/0081_status_task.cpython-312.pyc b/osinaweb/osinacore/migrations/__pycache__/0081_status_task.cpython-312.pyc
new file mode 100644
index 00000000..c5634a5e
Binary files /dev/null and b/osinaweb/osinacore/migrations/__pycache__/0081_status_task.cpython-312.pyc differ
diff --git a/osinaweb/osinacore/templates/main.html b/osinaweb/osinacore/templates/main.html
index 15fc7636..13891b07 100644
--- a/osinaweb/osinacore/templates/main.html
+++ b/osinaweb/osinacore/templates/main.html
@@ -47,8 +47,7 @@
class="w-full h-full bg-black bg-opacity-40 z-20 fixed hidden justify-center items-center inset-0 p-5">
-
-
+
diff --git a/osinaweb/static/dist/output.css b/osinaweb/static/dist/output.css
index e3999796..a12aef20 100644
--- a/osinaweb/static/dist/output.css
+++ b/osinaweb/static/dist/output.css
@@ -1056,6 +1056,10 @@ video {
height: 2.5rem;
}
+.h-12 {
+ height: 3rem;
+}
+
.h-14 {
height: 3.5rem;
}
@@ -1234,10 +1238,6 @@ video {
height: 100vh;
}
-.h-12 {
- height: 3rem;
-}
-
.max-h-\[50px\] {
max-height: 50px;
}
@@ -1254,6 +1254,10 @@ video {
width: 2.5rem;
}
+.w-12 {
+ width: 3rem;
+}
+
.w-14 {
width: 3.5rem;
}
@@ -1334,10 +1338,6 @@ video {
width: 220px;
}
-.w-\[22px\] {
- width: 22px;
-}
-
.w-\[240px\] {
width: 240px;
}
@@ -1447,10 +1447,6 @@ video {
width: 100%;
}
-.w-12 {
- width: 3rem;
-}
-
.min-w-full {
min-width: 100%;
}
@@ -2459,6 +2455,10 @@ video {
--tw-gradient-to: #fff var(--tw-gradient-to-position);
}
+.fill-blue-600 {
+ fill: #2563eb;
+}
+
.fill-osiblue {
fill: #20336b;
}
@@ -2467,10 +2467,6 @@ video {
fill: #374a7a;
}
-.fill-blue-600 {
- fill: #2563eb;
-}
-
.stroke-black {
stroke: #000;
}
@@ -3650,8 +3646,8 @@ video {
height: 70px;
}
- .md\:w-\[160px\] {
- width: 160px;
+ .md\:w-\[250px\] {
+ width: 250px;
}
.md\:w-\[300px\] {
@@ -3663,10 +3659,6 @@ video {
width: fit-content;
}
- .md\:w-\[250px\] {
- width: 250px;
- }
-
.md\:grid-cols-2 {
grid-template-columns: repeat(2, minmax(0, 1fr));
}
diff --git a/osinaweb/static/js/side-bar.js b/osinaweb/static/js/side-bar.js
index 4e425307..44f394dd 100644
--- a/osinaweb/static/js/side-bar.js
+++ b/osinaweb/static/js/side-bar.js
@@ -72,13 +72,14 @@ document.addEventListener('DOMContentLoaded', function () {
// TO DISPLAY THE USER PROFILE DROPDOWN ON MOBILE
const mobileUserProfile = document.getElementById('mobileUserProfile');
var dropdown = document.getElementById('mobileUserProfileDropdown');
- var arrowDown = menuItem.querySelector('.angleDown');
- var arrowUp = menuItem.querySelector('.angleUp');
+ const mobileArrowDown = document.querySelector('#mobileUserProfile .fa-angle-down');
+ const mobileArrowUp = document.querySelector('#mobileUserProfile .fa-angle-up');
+
mobileUserProfile.addEventListener('click', function () {
dropdown.classList.toggle('active');
- arrowDown.style.display = arrowDown.style.display === 'none' ? 'inline' : 'none';
- arrowUp.style.display = arrowUp.style.display === 'none' ? 'inline' : 'none';
+ mobileArrowDown.style.display = mobileArrowDown.style.display === 'none' ? 'inline' : 'none';
+ mobileArrowUp.style.display = mobileArrowUp.style.display === 'none' ? 'inline' : 'none';
});
});
diff --git a/osinaweb/static/js/projects-filtering.js b/osinaweb/static/js/projects-filtering.js
index ebbdecdb..d9988451 100644
--- a/osinaweb/static/js/projects-filtering.js
+++ b/osinaweb/static/js/projects-filtering.js
@@ -19,10 +19,12 @@ document.addEventListener('DOMContentLoaded', function () {
allProjectsContainer.classList.remove('hidden');
projectLoader.classList.add('hidden');
- // Check if "Pending" is selected
- } else if (selectedStatus === 'Pending') {
+ // Check if "In Progress" is selected
+ } else if (selectedStatus === 'In Progress') {
inProgressProjectsContainer.classList.remove('hidden');
+ projectsByStatusContainer.classList.add('hidden');
projectLoader.classList.add('hidden');
+ allProjectsContainer.classList.add('hidden');
} else {
fetch('/projects/status/' + selectedStatus + '/')
.then(response => response.text())